Learn R Programming

SNPassoc (version 1.0-2)

SNPs.info.pos: Genomic position for selected SNPs

Description

This data.frame contains information about the SNPs regarding their genomic position and the gene where they are located for those SNPs in the data.frame SNPs.

Usage

data(SNPs.info.pos)

Arguments

source

Data obtained from our department. The reference and details will be supplied after being published.

See Also

SNPs