Learn R Programming

SNPassoc (version 1.1-1)

WGstats: Statistics for an object of class 'WGassociation'

Description

Gives a sort summary for each chromosome (or gene) for an object of class 'WGassociation'

Usage

WGstats(x, pSig = 1e-06)

Arguments

x
an object of class WGassociation
pSig
level of significance. The default is 0.000001. See details

Value

  • a data frame where rows are chromosomes (or genes) and the following columns: number of SNPs, percentage of SNPs with genotype rate less than 'genotypingRate', the percentage of Monomorphic SNPs, and the number of statistically significant associations at level indicated in 'pSig'.

Details

The function computes, for each chromosome (or gene), the number of SNPs, the percentage of SNPs with genotype error (e.g SNPs where the genotype rate is less than those indicated in the argument 'genotypingRate' from WGassociation function), the percentage of Monomorphic SNPs, and the number of statistically significant associations at level given in the 'pSig' argument.

See Also

WGassociation

Examples

Run this code
data(HapMap)
WGstats(resHapMap)

Run the code above in your browser using DataLab