SNPs.info.pos: Genomic position for selected SNPs
Description
This data.frame contains information about the SNPs regarding their
genomic position and the gene where they are located for those SNPs
in the data.frame SNPs.source
Data obtained from our department. The reference and details will be supplied after being published.